==> skga-0.0.4.tar.gz: skga-0.0.4/setup.py <==
from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="skga",
    version="0.0.4",
    description="The python package implementing the HyperBRKGA algorithm optimizes hyperparameters of machine learning algorithms through a hybrid approach based on genetic algorithms.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MLRG-CEFET-RJ/skga",
    author="Leonardo Sauberman, João Pedro Nogueira, Eduardo Bezerra",
    author_email="leonardo.moraes@aluno.cefet-rj.br, joao.carneiro@aluno.cefet-rj.br, ebezerra@cefet-rj.br",
    license="BSD License",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    packages=["skga", "hbrkga"],
    include_package_data=True,
    install_requires=[
        "bayesian-optimization==1.2.0",
        "bleach==6.0.0",
        "build==0.10.0",
        "certifi==2023.5.7",
        "charset-normalizer==3.1.0",
        "contourpy==1.0.7",
        "cycler==0.11.0",
        "Cython==0.29.30",
        "docutils==0.19",
        "fonttools==4.39.3",
        "idna==3.4",
        "importlib-metadata==6.6.0",
        "importlib-resources==5.12.0",
        "jaraco.classes==3.2.3",
        "joblib==1.2.0",
        "keyring==23.13.1",
        "kiwisolver==1.4.4",
        "markdown-it-py==2.2.0",
        "matplotlib==3.7.1",
        "mdurl==0.1.2",
        "more-itertools==9.1.0",
        "numpy==1.23.1",
        "packaging==23.1",
        "pandas==1.4.3",
        "Pillow==9.5.0",
        "pkginfo==1.9.6",
        "Pygments==2.15.1",
        "pyparsing==3.0.9",
        "python-dateutil==2.8.2",
        "pyproject_hooks==1.0.0",
        "pytz==2023.3",
        "readme-renderer==37.3",
        "requests==2.30.0",
        "requests-toolbelt==1.0.0",
        "rfc3986==2.0.0",
        "rich==13.3.5",
        "scikit-learn==1.1.2",
        "scipy==1.8.1",
        "seaborn==0.12.1",
        "six==1.16.0",
        "threadpoolctl==3.1.0",
        "tomli==2.0.1",
        "torch==1.9.0",
        "twine==4.0.2",
        "urllib3==1.26.15",
        "webencodings==0.5.1",
        "wheel==0.40.0",
        "xgboost==1.7.1",
        "zipp==3.15.0",
    ],
)

==> skga-0.0.8.tar.gz: skga-0.0.8/setup.py <==
from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="skga",
    version="0.0.8",
    description="The python package implementing the HyperBRKGA algorithm optimizes hyperparameters of machine learning algorithms through a hybrid approach based on genetic algorithms.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MLRG-CEFET-RJ/skga",
    author="Leonardo Sauberman, João Pedro Nogueira, Eduardo Bezerra",
    author_email="leonardo.moraes@aluno.cefet-rj.br, joao.carneiro@aluno.cefet-rj.br, ebezerra@cefet-rj.br",
    license="BSD License",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    packages=["skga", "skga.hbrkga"],
    include_package_data=True,
    install_requires=[
        "bayesian-optimization==1.2.0",
        "bleach==6.0.0",
        "build==0.10.0",
        "certifi==2023.5.7",
        "charset-normalizer==3.1.0",
        "contourpy==1.0.7",
        "cycler==0.11.0",
        "Cython==0.29.30",
        "docutils==0.19",
        "fonttools==4.39.3",
        "idna==3.4",
        "importlib-metadata==6.6.0",
        "importlib-resources==5.12.0",
        "jaraco.classes==3.2.3",
        "joblib==1.2.0",
        "keyring==23.13.1",
        "kiwisolver==1.4.4",
        "markdown-it-py==2.2.0",
        "matplotlib==3.7.1",
        "mdurl==0.1.2",
        "more-itertools==9.1.0",
        "numpy==1.23.1",
        "packaging==23.1",
        "pandas==1.4.3",
        "Pillow==9.5.0",
        "pkginfo==1.9.6",
        "Pygments==2.15.1",
        "pyparsing==3.0.9",
        "python-dateutil==2.8.2",
        "pyproject_hooks==1.0.0",
        "pytz==2023.3",
        "readme-renderer==37.3",
        "requests==2.30.0",
        "requests-toolbelt==1.0.0",
        "rfc3986==2.0.0",
        "rich==13.3.5",
        "scikit-learn==1.1.2",
        "scipy==1.8.1",
        "seaborn==0.12.1",
        "six==1.16.0",
        "threadpoolctl==3.1.0",
        "tomli==2.0.1",
        "torch==1.9.0",
        "twine==4.0.2",
        "urllib3==1.26.15",
        "webencodings==0.5.1",
        "wheel==0.40.0",
        "xgboost==1.7.1",
        "zipp==3.15.0",
    ],
)
